Comparison

Struct Comparison 

pub struct Comparison<'a, TLeft, TRight>
where TLeft: ?Sized, TRight: ?Sized,
{ /* private fields */ }
A comparison of two values.

Where both values implement Debug, the comparison can be displayed as a pretty diff.

use pretty_assertions::Comparison;

print!("{}", Comparison::new(&123, &134));

The values may have different types, although in practice they are usually the same.

Implementations

Source

impl<'a, TLeft, TRight> Comparison<'a, TLeft, TRight>
where TLeft: ?Sized, TRight: ?Sized,

pub fn new(left: &'a TLeft, right: &'a TRight) -> Comparison<'a, TLeft, TRight>

Store two values to be compared in future.

Expensive diffing is deferred until calling Debug::fmt.